==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/panel/translations/lxqt-panel_fa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>افزودن افزونه ها</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>جستجو:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>افزودن ابزارک</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(تنها یک نسخه می‌تواند به طور همزمان اجرا شود)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>بخش تنظیمات</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>پنل</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>ابزارک ها</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>پنل پیکربندی</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>اندازه</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>اندازه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>طول:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>اندازه آیکون:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>صفر به معنای عدم اجرای انیمیشن است</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>صفر به معنای بدون وقفه می‌باشد</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>نمایش با وقفه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="561"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="571"/>
        <source>Override icon &amp;theme</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="586"/>
        <source>Icon theme for panels:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>مدت زمان انیمیشن:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation>سطر ها:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="206"/>
        <source>Left</source>
        <translation>چپ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="207"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Center</source>
        <translation>مرکز</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="208"/>
        <source>Right</source>
        <translation>راست</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>رنگ فونت:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>رنگ پس زمینه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>شفافیت پس زمینه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>تصویر پس زمینه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="172"/>
        <source>Top of desktop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="173"/>
        <source>Left of desktop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="174"/>
        <source>Right of desktop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="175"/>
        <source>Bottom of desktop</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="184"/>
        <source>Top of desktop %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="185"/>
        <source>Left of desktop %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="186"/>
        <source>Right of desktop %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="187"/>
        <source>Bottom of desktop %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <source>Top</source>
        <translation>بالا</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="214"/>
        <source>Bottom</source>
        <translation>پایین</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="430"/>
        <location filename="../config/configpanelwidget.cpp" line="446"/>
        <source>Pick color</source>
        <translation>انتخاب رنگ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Pick image</source>
        <translation>انتخاب تصویر</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="464"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>تصاویر (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>پیکربندی افزونه ها</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>افزودن</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>پیکربندی</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1068"/>
        <location filename="../lxqtpanel.cpp" line="1094"/>
        <source>Panel</source>
        <translation>پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1097"/>
        <source>Configure Panel</source>
        <translation>پیکربندی پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1102"/>
        <source>Manage Widgets</source>
        <translation>مدیریت ابزارک ها</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1108"/>
        <source>Add New Panel</source>
        <translation>افزودن پنل جدید</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1115"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>حذف پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1120"/>
        <source>Lock This Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1273"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>حذف پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1274"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="411"/>
        <source>Configure &quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="416"/>
        <source>Move &quot;%1&quot;</source>
        <translation>انتقال &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="424"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>حذف &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>فایل پیکربندی</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/panel/translations/lxqt-panel_fa.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fa">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>افزودن افزونه ها</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>جستجو:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>افزودن ابزارک</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>بستن</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(تنها یک نسخه می‌تواند به طور همزمان اجرا شود)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>بخش تنظیمات</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>پنل</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>ابزارک ها</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>پنل پیکربندی</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>اندازه</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>اندازه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>طول:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="109"/>
        <location filename="../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>اندازه آیکون:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="262"/>
        <location filename="../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>صفر به معنای عدم اجرای انیمیشن است</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="288"/>
        <location filename="../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="301"/>
        <location filename="../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>صفر به معنای بدون وقفه می‌باشد</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>نمایش با وقفه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>حاشیه نازک قابل مشاهده برای پنل پنهان</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="337"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="340"/>
        <source>Reserve space on display</source>
        <translation>رزرو فضا بر روی صفحه نمایش</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="568"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="578"/>
        <source>Override icon &amp;theme</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="593"/>
        <source>Icon theme for panels:</source>
        <translation>تم آیکون برای پنل‌ها:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>موقعیت:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>مدت زمان انیمیشن:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="173"/>
        <source>Rows:</source>
        <translation>سطر ها:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="219"/>
        <location filename="../config/configpanelwidget.cpp" line="211"/>
        <source>Left</source>
        <translation>چپ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="224"/>
        <location filename="../config/configpanelwidget.cpp" line="212"/>
        <location filename="../config/configpanelwidget.cpp" line="218"/>
        <source>Center</source>
        <translation>مرکز</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="229"/>
        <location filename="../config/configpanelwidget.cpp" line="213"/>
        <source>Right</source>
        <translation>راست</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="356"/>
        <source>Custom styling</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="377"/>
        <source>Font color:</source>
        <translation>رنگ قلم:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="417"/>
        <source>Background color:</source>
        <translation>رنگ پس زمینه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="456"/>
        <source>Background opacity:</source>
        <translation>شفافیت پس زمینه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="488"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.ui" line="516"/>
        <source>Background image:</source>
        <translation>تصویر پس زمینه:</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="177"/>
        <source>Top of desktop</source>
        <translation>بالای دسکتاپ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="178"/>
        <source>Left of desktop</source>
        <translation>سمت چپ دسکتاپ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="179"/>
        <source>Right of desktop</source>
        <translation>سمت راست دسکتاپ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="180"/>
        <source>Bottom of desktop</source>
        <translation>پایین دسکتاپ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="189"/>
        <source>Top of desktop %1</source>
        <translation>بالای دسکتاپ %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="190"/>
        <source>Left of desktop %1</source>
        <translation>سمت چپ دسکتاپ %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="191"/>
        <source>Right of desktop %1</source>
        <translation>سمت راست دسکتاپ %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="192"/>
        <source>Bottom of desktop %1</source>
        <translation>پایین دسکتاپ %1</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="217"/>
        <source>Top</source>
        <translation>بالا</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="219"/>
        <source>Bottom</source>
        <translation>پایین</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="436"/>
        <location filename="../config/configpanelwidget.cpp" line="452"/>
        <source>Pick color</source>
        <translation>انتخاب رنگ</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="470"/>
        <source>Pick image</source>
        <translation>انتخاب تصویر</translation>
    </message>
    <message>
        <location filename="../config/configpanelwidget.cpp" line="470"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>تصاویر (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>پیکربندی افزونه ها</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>توجه: تغییرات ایجاد شده در این صفحه قابل تنظیم مجدد نیست.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>حرکت به بالا</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>حرکت به پایین</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>افزودن</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>پیکربندی</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1081"/>
        <location filename="../lxqtpanel.cpp" line="1107"/>
        <source>Panel</source>
        <translation>پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1110"/>
        <source>Configure Panel</source>
        <translation>پیکربندی پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1115"/>
        <source>Manage Widgets</source>
        <translation>مدیریت ابزارک ها</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1121"/>
        <source>Add New Panel</source>
        <translation>افزودن پنل جدید</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1128"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>حذف پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1133"/>
        <source>Lock This Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1286"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>حذف پنل</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1287"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="432"/>
        <source>Configure &quot;%1&quot;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="437"/>
        <source>Move &quot;%1&quot;</source>
        <translation>انتقال &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="445"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>حذف &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>پرونده پیکربندی</translation>
    </message>
</context>
</TS>
